@@ -17,7 +17,7 @@ class StateTestCase(unittest2.TestCase):
     def test_repr(self):
         a = base.State('foo', 'Foo')
         self.assertIn('foo', repr(a))
-        self.assertIn('Foo', repr(a))
+        self.assertNotIn('Foo', repr(a))
 
 
 class StateListTestCase(unittest2.TestCase):
@@ -102,7 +102,7 @@ class TransitionListTestCase(unittest2.TestCase):
         self.assertEqual([], list(self.tl.available_from(self.baz)))
 
 
-class StateFieldTestCase(unittest2.TestCase):
+class StateWrapperTestCase(unittest2.TestCase):
 
     def setUp(self):
         class MyWorkflow(base.Workflow):
@@ -117,15 +117,15 @@ class StateFieldTestCase(unittest2.TestCase):
         self.foo = base.State('foo', 'Foo')
         self.bar = base.State('bar', 'Bar')
         self.wf = MyWorkflow
-        self.sf = base.StateField(self.foo, self.wf)
+        self.sf = base.StateWrapper(self.foo, self.wf)
 
     def test_comparison(self):
         self.assertEqual(self.sf, self.foo)
         self.assertEqual(self.foo, self.sf)
         self.assertNotEqual(self.sf, self.bar)
         self.assertNotEqual(self.bar, self.sf)
-        self.assertNotEqual(self.sf, 'foo')
-        self.assertNotEqual('foo', self.sf)
+        self.assertEqual(self.sf, 'foo')
+        self.assertEqual('foo', self.sf)
 
     def test_attributes(self):
         self.assertTrue(self.sf.is_foo)
@@ -148,7 +148,7 @@ class TransitionImplementationTestCase(unittest2.TestCase):
             """doc for blah"""
             pass
 
-        impl = base.TransitionImplementation(self.foobar, 'my_state', blah)
+        impl = base.TransitionImplementation(self.foobar, 'my_state', None, blah)
 
         self.assertIn("'foobar'", repr(impl))
         self.assertIn("blah", repr(impl))
@@ -162,7 +162,7 @@ class TransitionImplementationTestCase(unittest2.TestCase):
         class MyClass(object):
             state = self.foo
 
-        implem = base.TransitionImplementation(self.foobar, 'my_state', blah)
+        implem = base.TransitionImplementation(self.foobar, 'my_state', None, blah)
 
         MyClass.foobar = implem
 
@@ -172,19 +172,6 @@ class TransitionImplementationTestCase(unittest2.TestCase):
 
         self.assertRaises(TypeError, getattr, o, 'foobar')
 
-    def test_copy(self):
-        def blah(obj):
-            """docstring for blah"""
-            pass
-
-        impl = base.TransitionImplementation(self.foobar, 'my_state', blah)
-
-        copy = impl.copy()
-        self.assertEqual(copy.transition, impl.transition)
-        self.assertEqual(copy.field_name, impl.field_name)
-        self.assertEqual(copy.implementation, impl.implementation)
-        self.assertEqual(copy.__doc__, 'docstring for blah')
-
 
 class TransitionWrapperTestCase(unittest2.TestCase):
 
@@ -194,27 +181,6 @@ class TransitionWrapperTestCase(unittest2.TestCase):
     def test_txt(self):
         self.assertIn('foobar', repr(self.wrapper))
 
-    def test_using(self):
-        def blah(obj):
-            pass
-
-        tr = base.Transition('foobar', base.State('foo'), base.State('bar'))
-
-        res = self.wrapper(blah).get_implem(tr, 'my_state')
-        self.assertEqual(tr, res.transition)
-        self.assertEqual(blah, res.implementation)
-        self.assertEqual('my_state', res.field_name)
-
-    def test_invalid_use(self):
-        @self.wrapper
-        def blah(obj):
-            pass
-
-        tr = base.Transition('foobaz', base.State('foo'), base.State('baz'))
-
-        self.assertRaises(ValueError, self.wrapper.get_implem, tr, 'my_state')
-
-
 
 if __name__ == '__main__':
     unittest2.main()
