@@ -126,157 +126,6 @@ class WorkflowDeclarationTestCase(unittest2.TestCase):
         self.assertRaises(TypeError, create_invalid_workflow_4)
 
 
-class WorkflowDeclarationImplementationsTestCase(unittest2.TestCase):
-
-    def test_simple_implementation(self):
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            def foobar(self):
-                return 42
-
-        implem = MyWorkflow.implementations['foobar']
-        self.assertEqual('state', implem.field_name)
-        self.assertEqual(MyWorkflow.transitions.foobar, implem.transition)
-        self.assertIn('foobar', MyWorkflow.implementations)
-        self.assertIn("'foobar'", repr(MyWorkflow.implementations))
-
-    def test_renamed_state_field_implementation(self):
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-            state_field = 'my_state'
-
-            def foobar(self):
-                return 42
-
-        implem = MyWorkflow.implementations['foobar']
-        self.assertEqual('my_state', implem.field_name)
-        self.assertEqual(MyWorkflow.transitions.foobar, implem.transition)
-
-    def test_renamed_implementation(self):
-
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            @base.transition('foobar')
-            def blah(self):
-                pass
-
-            def foobar(self):
-                pass
-
-        self.assertEqual(MyWorkflow.blah.func,
-                         MyWorkflow.implementations['foobar'].implementation)
-
-    def test_conflicting_implementations(self):
-        def create_invalid_workflow():
-            class MyWorkflow(base.Workflow):
-                states = ('foo', 'bar', 'baz')
-                transitions = (
-                    ('foobar', 'foo', 'bar'),
-                    ('gobaz', ('foo', 'bar'), 'baz'),
-                    ('bazbar', 'baz', 'bar'),
-                )
-                initial_state = 'foo'
-
-                @base.transition('foobar')
-                def blah(self):
-                    pass
-
-                @base.transition('foobar')
-                def blih(self):
-                    pass
-
-        self.assertRaises(ValueError, create_invalid_workflow)
-
-    def test_not_callable_implementation(self):
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            foobar = 42
-
-        self.assertNotIn('foobar', MyWorkflow.implementations)
-
-    def test_wrapping_unknwon_implementation(self):
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            @base.transition('blah')
-            def blih(self):
-                pass
-
-    def test_conflicting_implementation(self):
-
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            @base.transition('foobar')
-            def gobar(self):
-                pass
-
-            def foobar(self):
-                pass
-
-    def test_inverted_implementations(self):
-        class MyWorkflow(base.Workflow):
-            states = ('foo', 'bar', 'baz')
-            transitions = (
-                ('foobar', 'foo', 'bar'),
-                ('gobaz', ('foo', 'bar'), 'baz'),
-                ('bazbar', 'baz', 'bar'),
-            )
-            initial_state = 'foo'
-
-            @base.transition('foobar')
-            def gobaz(self):
-                return 1
-
-            @base.transition('gobaz')
-            def foobar(self):
-                return 2
-
-        self.assertEqual(MyWorkflow.gobaz.func,
-                         MyWorkflow.implementations['foobar'].implementation)
-        self.assertEqual(MyWorkflow.foobar.func,
-                         MyWorkflow.implementations['gobaz'].implementation)
-
-
 class WorkflowEnabledTestCase(unittest2.TestCase):
     def setUp(self):
         class MyWorkflow(base.Workflow):
@@ -306,15 +155,6 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
         self.assertEqual(self.MyWorkflow.initial_state, obj.state)
         self.assertEqual(2, len(list(obj.state.transitions())))
 
-    def test_alt_state_field(self):
-        class MyWorkflowObject(base.WorkflowEnabled):
-            wf = self.MyWorkflow('my_state')
-
-        obj = MyWorkflowObject()
-        self.assertEqual(self.MyWorkflow.initial_state, obj.my_state)
-        self.assertTrue(isinstance(obj.wf, self.MyWorkflow))
-        self.assertFalse(hasattr(obj, 'state'))
-
     def test_state_setting(self):
         class MyWorkflowObject(base.WorkflowEnabled):
             state = self.MyWorkflow()
@@ -323,20 +163,10 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
 
         self.assertRaises(ValueError, setattr, obj, 'state', base.State('a', 'A'))
 
-    def test_state_field_conflict(self):
-        self.MyWorkflow.state_field = 'state'
-
-        def create_invalid_workflow_enabled():
-            class MyWorkflowObject(base.WorkflowEnabled):
-                wf = self.MyWorkflow
-                state = 42
-
-        self.assertRaises(ValueError, create_invalid_workflow_enabled)
-
     def test_implementation_conflict(self):
         def create_invalid_workflow_enabled():
             class MyWorkflowObject(base.WorkflowEnabled):
-                wf = self.MyWorkflow
+                wf = self.MyWorkflow()
                 foobar = 42
 
         self.assertRaises(ValueError, create_invalid_workflow_enabled)
@@ -355,9 +185,13 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
             def blah(self):
                 pass
 
-        class MyWorkflowObject(base.WorkflowEnabled):
-            foobar = 42
-            wf = MyWorkflow
+        def create_invalid_workflow_enabled():
+            class MyWorkflowObject(base.WorkflowEnabled):
+                foobar = 42
+                wf = MyWorkflow()
+
+        # No implementation for 'foobar' - data from the Workflow was ignored.
+        self.assertRaises(ValueError, create_invalid_workflow_enabled)
 
     def test_override_renamed(self):
         class MyWorkflow(base.Workflow):
@@ -373,7 +207,7 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
                 pass
 
         class MyWorkflowObject(base.WorkflowEnabled):
-            wf = MyWorkflow
+            wf = MyWorkflow()
 
             @base.transition('foobar')
             def blah(self):
@@ -396,7 +230,7 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
 
         def create_invalid_workflow_enabled():
             class MyWorkflowObject(base.WorkflowEnabled):
-                wf = MyWorkflow
+                wf = MyWorkflow()
 
                 @base.transition('gobaz')
                 def foobar(self):
@@ -419,7 +253,7 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
 
         def create_invalid_workflow_enabled():
             class MyWorkflowObject(base.WorkflowEnabled):
-                wf = MyWorkflow
+                wf = MyWorkflow()
 
                 @base.transition('blah')
                 def foobar(self):
@@ -442,7 +276,7 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
 
         def create_invalid_workflow_enabled():
             class MyWorkflowObject(base.WorkflowEnabled):
-                wf = MyWorkflow
+                wf = MyWorkflow()
 
                 foobar = 42
 
@@ -459,15 +293,6 @@ class WorkflowEnabledTestCase(unittest2.TestCase):
 
         self.assertRaises(ValueError, create_invalid_workflow_enabled)
 
-    def test_dual_workflows_state_field_conflict(self):
-
-        def create_invalid_workflow_enabled():
-            class MyWorkflowObject(base.WorkflowEnabled):
-                wf1 = self.MyWorkflow(state_field='foo')
-                wf2 = self.MyWorkflow(state_field='foo')
-
-        self.assertRaises(ValueError, create_invalid_workflow_enabled)
-
     def test_dual_workflows(self):
         class MyAltWorkflow(base.Workflow):
             states = ('foo', 'bar', 'baz')
@@ -504,7 +329,7 @@ class TransitionRunningTestCase(unittest2.TestCase):
             initial_state = 'foo'
 
         class MyWorkflowObject(base.WorkflowEnabled):
-            state = MyWorkflow
+            state = MyWorkflow()
 
         self.MyWorkflow = MyWorkflow
         self.MyWorkflowObject = MyWorkflowObject
@@ -545,8 +370,8 @@ class TransitionRunningTestCase(unittest2.TestCase):
             initial_state = 'foo'
 
         class MyWorkflowObject(base.WorkflowEnabled):
-            state1 = self.MyWorkflow
-            state2 = MyAltWorkflow
+            state1 = self.MyWorkflow()
+            state2 = MyAltWorkflow()
 
         obj = MyWorkflowObject()
 
@@ -580,7 +405,7 @@ class CustomImplementationTestCase(unittest2.TestCase):
         obj = MyWorkflowObject()
 
         self.assertEqual(self.MyWorkflow.states.foo, obj.state)
-        self.assertEqual('blah', obj.foobar('blah'))
+        self.assertEqual(None, obj.foobar('blah'))  # Workflow method ignored.
         self.assertEqual(self.MyWorkflow.states.bar, obj.state)
 
     def test_instance_defined(self):
@@ -647,36 +472,18 @@ class ExtendedTransitionImplementationTestCase(unittest2.TestCase):
     def test_implementation(self):
         class MyImplementation(base.TransitionImplementation):
             """Custom TransitionImplementation, with extra kwarg 'blah'."""
-            extra_kwargs = {'blah': 42}
 
-            @classmethod
-            def copy_from(cls, implem):
-                return cls(implem.transition, implem.field_name, implem.implementation)
+            def _post_transition(self, instance, res, *args, **kwargs):
+                super(MyImplementation, self)._post_transition(instance, res, *args, **kwargs)
+                instance.blah = kwargs.get('blah', 42)
 
-            def _post_transition(self, instance, res, cls_kwargs, *args, **kwargs):
-                super(MyImplementation, self)._post_transition(instance, res, cls_kwargs, *args, **kwargs)
-                instance.blah = cls_kwargs['blah']
+        class MyWorkflow(self.MyWorkflow):
+            implementation_class = MyImplementation
 
-        # Helpers in order to use MyImplementation instead of base.TransitionImplementation
-        class MyImplementationList(base.ImplementationList):
-            @classmethod
-            def _add_implem(cls, attrs, attrname, implem):
-                attrs[attrname] = MyImplementation.copy_from(implem)
+        class MyWorkflowObject(base.WorkflowEnabled):
+            state = MyWorkflow()
 
-        class MyWorkflowEnabledMeta(base.WorkflowEnabledMeta):
-            @classmethod
-            def _copy_implems(mcs, workflow, state_field):
-                return MyImplementationList.copy_from(workflow.implementations,
-                                                      state_field=state_field)
-
-        class MyWorkflowEnabled(base.BaseWorkflowEnabled):
-            __metaclass__ = MyWorkflowEnabledMeta
-
-
-        class MyWorkflowObject(MyWorkflowEnabled):
-            state = self.MyWorkflow()
-
-            def foobar(self):
+            def foobar(self, **kwargs):
                 return 1
 
             def gobaz(self, blah=10):
